Changes — configaro 0.9.7 documentation

# Changes

## 0.9.7

### Features

- improvements to API documentation

## 0.9.6

### Features

- improvements to Usage documentation

## 0.9.5

### Features

- `configaro.get()` now accepts default keyword arg to pass value to be returned if property is not found, instead of raising error
- expanded test coverage
- added coverage checks to tox tests
- added style checks to tox tests
- improvements to documentation

## 0.9.4

### Features

- tox automation
- improvements to documentation
- improvements to `configaro.put()` API

### Changes

- converted to single module library
- removed duplication of release metadata
- renamed `configaro.initialize()` to `configaro.init()`

## 0.9.3

### Fixes

- documentation build fixes

## 0.9.2

### Fixes

- packaging and requirements fixes

### Deletions

- `configaro.render()`

## 0.9.1

### Features

- documentation improvements

## 0.9.0

Initial release of configaro.

### Features

- a simple API that is easy to use and gets out of your way
- a system that allows for hierarchical configuration data that supports dot-addressable property access
- a system that allows for configuration defaults and local overrides
- a system with high degree of test coverage
- a system with high degree of documentation

### Fixes

- none

### Changes

- none

### Deprecations

- none

### Deletions

- none